==> SugarCE-6.1.4.zip: SugarCE-Full-6.1.4/include/generic/SugarWidgets/SugarWidgetFieldtext.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/


class SugarWidgetFieldText extends SugarWidgetFieldVarchar
{
    function SugarWidgetFieldText(&$layout_manager) {
        parent::SugarWidgetFieldVarchar($layout_manager);
        $this->reporter = $this->layout_manager->getAttribute('reporter');  
    }

    function queryFilterEquals(&$layout_def) {
        if( $this->reporter->db->dbType == 'mysql') {
            return parent::queryFilterEquals($layout_def);
        } 
        elseif( $this->reporter->db->dbType == 'mssql') {
            //return parent::queryFilterEquals($layout_def);
			return $this->_get_column_select($layout_def)." like '".$GLOBALS['db']->quote($layout_def['input_name0'])."'\n";
            
        }
    }

    function queryFilterNot_Equals_Str(&$layout_def) {
        if( $this->reporter->db->dbType == 'mysql') {
            return parent::queryFilterNot_Equals_Str($layout_def);
        } 
        elseif( $this->reporter->db->dbType == 'mssql') {
            return parent::queryFilterNot_Equals_Str($layout_def);
        }
    }
    
    function queryFilterNot_Empty(&$layout_def) {
        if( $this->reporter->db->dbType == 'mysql') {
            return parent::queryFilterNot_Empty($layout_def);
        } 
        elseif( $this->reporter->db->dbType == 'mssql') {
            return '( '.$this->_get_column_select($layout_def).' IS NOT NULL OR DATALENGTH('.$this->_get_column_select($layout_def).") > 0)\n";
        }
    }
    
    function queryFilterEmpty(&$layout_def) {
        if( $this->reporter->db->dbType == 'mysql') {
            return parent::queryFilterEmpty($layout_def);
        } 
        elseif( $this->reporter->db->dbType == 'mssql') {
            return '( '.$this->_get_column_select($layout_def).' IS NULL OR DATALENGTH('.$this->_get_column_select($layout_def).") = 0)\n";
        }

    }
}

?>

==> SugarCE-6.2.0.zip: SugarCE-Full-6.2.0/include/generic/SugarWidgets/SugarWidgetFieldtext.php <==
<?php
if(!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');
/*********************************************************************************
 * SugarCRM Community Edition is a customer relationship management program developed by
 * SugarCRM, Inc. Copyright (C) 2004-2011 SugarCRM Inc.
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by the
 * Free Software Foundation with the addition of the following permission added
 * to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED WORK
 * IN WHICH THE COPYRIGHT IS OWNED BY SUGARCRM, SUGARCRM DISCLAIMS THE WARRANTY
 * OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License along with
 * this program; if not, see http://www.gnu.org/licenses or write to the Free
 * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA.
 * 
 * You can contact SugarCRM, Inc. headquarters at 10050 North Wolfe Road,
 * SW2-130, Cupertino, CA 95014, USA. or at email address contact@sugarcrm.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "Powered by
 * SugarCRM" logo. If the display of the logo is not reasonably feasible for
 * technical reasons, the Appropriate Legal Notices must display the words
 * "Powered by SugarCRM".
 ********************************************************************************/


class SugarWidgetFieldText extends SugarWidgetFieldVarchar
{
    function SugarWidgetFieldText(&$layout_manager) {
        parent::SugarWidgetFieldVarchar($layout_manager);
        $this->reporter = $this->layout_manager->getAttribute('reporter');  
    }

    function queryFilterEquals(&$layout_def) {
        if( $this->reporter->db->dbType == 'mysql') {
            return parent::queryFilterEquals($layout_def);
        } 
        elseif( $this->reporter->db->dbType == 'mssql') {
            //return parent::queryFilterEquals($layout_def);
			return $this->_get_column_select($layout_def)." like '".$GLOBALS['db']->quote($layout_def['input_name0'])."'\n";
            
        }
    }

    function queryFilterNot_Equals_Str(&$layout_def) {
        if( $this->reporter->db->dbType == 'mysql') {
            return parent::queryFilterNot_Equals_Str($layout_def);
        } 
        elseif( $this->reporter->db->dbType == 'mssql') {
            return parent::queryFilterNot_Equals_Str($layout_def);
        }
    }
    
    function queryFilterNot_Empty(&$layout_def) {
        if( $this->reporter->db->dbType == 'mysql') {
            return parent::queryFilterNot_Empty($layout_def);
        } 
        elseif( $this->reporter->db->dbType == 'mssql') {
            return '( '.$this->_get_column_select($layout_def).' IS NOT NULL OR DATALENGTH('.$this->_get_column_select($layout_def).") > 0)\n";
        }
    }
    
    function queryFilterEmpty(&$layout_def) {
        if( $this->reporter->db->dbType == 'mysql') {
            return parent::queryFilterEmpty($layout_def);
        } 
        elseif( $this->reporter->db->dbType == 'mssql') {
            return '( '.$this->_get_column_select($layout_def).' IS NULL OR DATALENGTH('.$this->_get_column_select($layout_def).") = 0)\n";
        }

    }
}

?>
